#
# MIT License
#
# Copyright 2021 NXP
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

import os
import glob
from mcutk.exceptions import ProjectNotFound
from mcutk.apps import eclipse

class Project(eclipse.Project):
    """Code Warrior project object

    This class could parser the settings in .cproject and .project.
    Parameters:
        prjpath: path of .project
    """

    @classmethod
    def frompath(cls, path):

        if os.path.isfile(path):
            return cls(path)

        for filepath in glob.glob(path + "/.project"):
            parts = os.path.abspath(filepath).replace("\\", "/").split("/")
            if "codewarrior" in parts or "cw" in parts:
                return cls(filepath)

        raise ProjectNotFound("not found Code Warrior project")
